@@ -36,6 +36,8 @@ type AsyncIoResult<'a, T> = Pin<Box<dyn Future<Output = IoResult<T>> + 'a + Send
 #[auto_impl(&, &mut, Box, Rc, Arc)]
 pub trait UploadTokenProvider: Clone + Debug + Sync + Send {
     /// 从上传凭证内获取 AccessKey
+    ///
+    /// 该方法的异步版本为 [`Self::async_access_key`]。
     fn access_key(&self, opts: GetAccessKeyOptions) -> ParseResult<GotAccessKey>;
 
     /// 异步从上传凭证内获取 AccessKey
@@ -47,6 +49,8 @@ pub trait UploadTokenProvider: Clone + Debug + Sync + Send {
     }
 
     /// 从上传凭证内获取上传策略
+    ///
+    /// 该方法的异步版本为 [`Self::async_policy`]。
     fn policy(&self, opts: GetPolicyOptions) -> ParseResult<GotUploadPolicy>;
 
     /// 异步从上传凭证内获取上传策略
@@ -58,6 +62,8 @@ pub trait UploadTokenProvider: Clone + Debug + Sync + Send {
     }
 
     /// 生成字符串
+    ///
+    /// 该方法的异步版本为 [`Self::async_to_token_string`]。
     fn to_token_string(&self, opts: ToStringOptions) -> IoResult<Cow<'_, str>>;
 
     /// 异步生成字符串
@@ -225,6 +231,8 @@ impl DerefMut for GotUploadPolicy<'_> {
 /// 提供存储空间名称解析方法
 pub trait UploadTokenProviderExt: UploadTokenProvider {
     /// 获取上传凭证中的存储空间名称
+    ///
+    /// 该方法的异步版本为 [`Self::async_bucket_name`]。
     fn bucket_name(&self, opts: GetPolicyOptions) -> ParseResult<BucketName> {
         self.policy(opts).and_then(|policy| {
             policy
@@ -272,6 +280,20 @@ impl StaticUploadTokenProvider {
             access_key: OnceCell::new(),
         }
     }
+
+    /// 获取上传凭证字符串
+    #[inline]
+    pub fn into_string(self) -> String {
+        self.upload_token.into_string()
+    }
+
+    pub(super) fn set_policy(&self, policy: UploadPolicy) {
+        self.policy.set(policy).ok();
+    }
+
+    pub(super) fn set_access_key(&self, access_key: AccessKey) {
+        self.access_key.set(access_key).ok();
+    }
 }
 
 impl Debug for StaticUploadTokenProvider {
@@ -343,7 +365,7 @@ impl FromStr for StaticUploadTokenProvider {
 
 /// 根据上传凭证生成上传策略
 ///
-/// 通过 [`UploadPolicy::into_upload_token_provider()`] 创建
+/// 通过 [`UploadPolicy::into_dynamic_upload_token_provider()`] 创建
 #[derive(Debug, Clone)]
 pub struct FromUploadPolicy<C: Clone> {
     upload_policy: UploadPolicy,
@@ -359,6 +381,12 @@ impl<C: Clone> FromUploadPolicy<C> {
             credential,
         }
     }
+
+    /// 同时返回构建时提供的上传策略和认证信息提供者
+    #[inline]
+    pub fn split(self) -> (UploadPolicy, C) {
+        (self.upload_policy, self.credential)
+    }
 }
 
 impl<C: CredentialProvider + Clone> UploadTokenProvider for FromUploadPolicy<C> {
@@ -367,7 +395,7 @@ impl<C: CredentialProvider + Clone> UploadTokenProvider for FromUploadPolicy<C>
             .credential
             .get(Default::default())?
             .into_credential()
-            .into_pair()
+            .split()
             .0
             .into())
     }
@@ -451,7 +479,7 @@ impl<C: CredentialProvider + Clone> UploadTokenProvider for BucketUploadTokenPro
             .credential
             .get(Default::default())?
             .into_credential()
-            .into_pair()
+            .split()
             .0
             .into())
     }
@@ -576,7 +604,7 @@ impl<C: CredentialProvider + Clone> UploadTokenProvider for ObjectUploadTokenPro
             .credential
             .get(Default::default())?
             .into_credential()
-            .into_pair()
+            .split()
             .0
             .into())
     }
